.. SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. place re-used URLs here, then include this file
.. on your other RST sources.

.. _idiap: http://www.idiap.ch
.. _cla: https://en.wikipedia.org/wiki/Contributor_License_Agreement
.. _project harmony: http://www.harmonyagreements.org/
.. _tto: mailto:tto@idiap.ch
.. _conda: https://conda.io
.. _python: http://www.python.org
.. _uv: https://github.com/astral-sh/uv
.. _pixi: https://pixi.sh
.. _pytorch: https://pytorch.org
.. _lightning: https://lightning.ai
.. _torchio: https://torchio.readthedocs.io/

.. Raw data websites
.. _montgomery: https://lhncbc.nlm.nih.gov/publication/pub9931
.. _shenzhen: https://lhncbc.nlm.nih.gov/publication/pub9931
.. _indian: https://sourceforge.net/projects/tbxpredict/
.. _PadChest: https://bimcv.cipf.es/bimcv-projects/padchest/
.. _TBX11K: https://mmcheng.net/tb/
.. _nih-cxr14-relabeled: https://stanfordmedicine.app.box.com/s/b3gk9qnanzrdocqge0pbuh07mreu5x7y

.. _drive: https://github.com/wfdubowen/Retina-Unet/tree/master/DRIVE/
.. _stare: http://cecas.clemson.edu/~ahoover/stare/
.. _hrf: https://www5.cs.fau.de/research/data/fundus-images/
.. _iostar: http://www.retinacheck.org/datasets
.. _chase-db1: https://blogs.kingston.ac.uk/retinal/chasedb1/
.. _drions-db: http://www.ia.uned.es/~ejcarmona/DRIONS-DB.html
.. _rim-one r3: http://medimrg.webs.ull.es/research/downloads/
.. _drishti-gs1: http://cvit.iiit.ac.in/projects/mip/drishti-gs/mip-dataset2/Home.php
.. _refuge: https://refuge.grand-challenge.org/Details/
.. _amd grand-challenge: https://amd.grand-challenge.org/
.. _drhagis: https://personalpages.manchester.ac.uk/staff/niall.p.mcloughlin/
.. _montgomery county: https://openi.nlm.nih.gov/faq#faq-tb-coll
.. _jsrt: http://db.jsrt.or.jp/eng.php
.. _jsrt-kaggle: https://www.kaggle.com/datasets/raddar/nodules-in-chest-xrays-jsrt
.. _cxr8: https://nihcc.app.box.com/v/ChestXray-NIHCC

.. Annotation data websites
.. _shenzhen annotations: https://www.kaggle.com/yoctoman/shcxr-lung-mask
.. _cxr8-annotations: https://github.com/lucasmansilla/NIH_chest_xray14_segmentations
.. _jsrt-annotations: https://www.isi.uu.nl/Research/Databases/SCR/download.php

.. models
.. _imagenet: https://www.image-net.org
.. _alexnet: https://en.wikipedia.org/wiki/AlexNet
.. _alexnet-pytorch: https://pytorch.org/hub/pytorch_vision_alexnet/
.. _densenet: https://arxiv.org/abs/1608.06993
.. _densenet-pytorch: https://pytorch.org/hub/pytorch_vision_densenet/
.. _logistic-regression: https://en.wikipedia.org/wiki/Logistic_regression
.. _mlp: https://en.wikipedia.org/wiki/Multilayer_perceptron
.. _lwnet: https://github.com/agaldran/lwnet
.. _unet: https://en.wikipedia.org/wiki/U-Net
.. _vgg-pytorch: https://pytorch.org/hub/pytorch_vision_vgg/
.. _mobilenetv2-pytorch: https://pytorch.org/hub/pytorch_vision_mobilenet_v2/

.. Baselines
.. _baseline-experiments: https://gitlab.idiap.ch/medai/software/mednet/-/ml/experiments
